@@ -131,3 +131,48 @@ tmp[, "crim"] <- tmp[p, "crim"]
 m2 <- Colr(Surv(cmedv, cmedv < 50) ~ chas + crim, data = tmp)
 stopifnot(all.equal(coef(m1), coef(as.mlt(m2)), tol = 1e-3))
 stopifnot(all.equal(logLik(m1), logLik(m2), tol = 1e-6))
+
+### contraints, by Lucas Kook
+data("GBSG2", package = "TH.data")
+# gave an error
+m <- Survreg(Surv(time, cens) ~ horTh + age, data = GBSG2, constraints = c("age >= 0"))
+
+### mtram with interval censoring, spotted by Sandra Siegfried
+dir <- system.file("rda", package = "TH.data")
+load(file.path(dir, "Primary_endpoint_data.rda"))
+trt <- "randarm5-FU + Oxaliplatin"
+### convert "exact" event dates to interval-censoring (+/- one day)
+tmp <- CAOsurv$iDFS
+exact <- tmp[,3] == 1 
+tmp[exact,2] <- tmp[exact,1] + 2
+tmp[exact,1] <- pmax(tmp[exact,1] - 2, 0)
+tmp[exact,3] <- 3
+CAOsurv$iDFS2 <- tmp
+CAO_SR <- Survreg(iDFS2 ~ randarm, data = CAOsurv, support = c(1, 1700), bounds = c(0, Inf))
+CAO_SR_mtram <- mtram(CAO_SR, ~ (1 | Block), data = CAOsurv)
+CAO_Cox <- Coxph(iDFS2 ~ randarm, data = CAOsurv, support = c(1, 1700), bounds = c(0, Inf), log_first = TRUE, order = 1)
+CAO_Cox_mtram <- mtram(CAO_Cox, ~ (1 | Block), data = CAOsurv)
+### wasn't equal
+stopifnot(isTRUE(all.equal(logLik(CAO_SR_mtram), logLik(CAO_Cox_mtram), tol = 1e-5)))
+
+## produces negative variances in shift-scale model
+set.seed(100)
+N <- 100
+sc <- -5.5
+sh <- 3
+ 
+FZ <- pnorm
+FZi <- qnorm
+h2y <- function(y) log(-FZ(y, lower.tail = FALSE, log.p = TRUE))
+ 
+x <- rep(x0 <- gl(2, 1), each = N)
+xx <- (0:1)[x]
+ 
+U <- runif(length(x))
+scale <- sqrt(exp(sc * xx))
+shift <- sh * xx
+d <- data.frame(y = h2y( shift + FZi(U) / scale),
+                x = x)
+m <- BoxCox(y ~ x | x, data = d, scale_shift = TRUE)
+coef(m)
+try(diag(vcov(m)))
